@@ -31,10 +31,10 @@ impl Backend for GoBackend {
     fn _list_remote_versions(&self) -> eyre::Result<Vec<String>> {
         self.remote_version_cache
             .get_or_try_init(|| {
-                let mut mod_path = Some(self.name());
+                let mut mod_path = Some(self.tool_name());
 
                 while let Some(cur_mod_path) = mod_path {
-                    let res = cmd!("go", "list", "-m", "-versions", "-json", cur_mod_path)
+                    let res = cmd!("go", "list", "-m", "-versions", "-json", &cur_mod_path)
                         .full_env(self.dependency_env()?)
                         .read();
                     if let Ok(raw) = res {
@@ -72,7 +72,7 @@ impl Backend for GoBackend {
         let install = |v| {
             CmdLineRunner::new("go")
                 .arg("install")
-                .arg(format!("{}@{v}", self.name()))
+                .arg(format!("{}@{v}", self.tool_name()))
                 .with_pr(ctx.pr.as_ref())
                 .envs(self.dependency_env()?)
                 .env("GOBIN", ctx.tv.install_path().join("bin"))
@@ -101,11 +101,8 @@ impl GoBackend {
     }
 }
 
-fn trim_after_last_slash(s: &str) -> Option<&str> {
-    match s.rsplit_once('/') {
-        Some((new_path, _)) => Some(new_path),
-        None => None,
-    }
+fn trim_after_last_slash(s: String) -> Option<String> {
+    s.rsplit_once('/').map(|(new_path, _)| new_path.to_string())
 }
 
 #[derive(Debug, serde::Deserialize)]
