@@ -2,6 +2,7 @@ use crate::backend::backend_type::BackendType;
 use crate::backend::{unalias_backend, ABackend};
 use crate::config::CONFIG;
 use crate::registry::REGISTRY;
+use crate::toolset::install_state::InstallStateTool;
 use crate::toolset::{install_state, parse_tool_options, ToolVersionOptions};
 use crate::{backend, config, dirs, registry};
 use contracts::requires;
@@ -49,6 +50,12 @@ impl<A: AsRef<str>> From<A> for BackendArg {
     }
 }
 
+impl From<InstallStateTool> for BackendArg {
+    fn from(ist: InstallStateTool) -> Self {
+        Self::new(ist.short, ist.full)
+    }
+}
+
 impl BackendArg {
     #[requires(!short.is_empty())]
     pub fn new(short: String, full: Option<String>) -> Self {
@@ -144,6 +151,13 @@ impl BackendArg {
         unalias_backend(&self.short).to_string()
     }
 
+    pub fn tool_name(&self) -> String {
+        let full = self.full();
+        let (_backend, tool_name) = full.split_once(':').unwrap_or(("", &full));
+        let tool_name = regex!(r#"\[.+\]$"#).replace_all(tool_name, "").to_string();
+        tool_name.to_string()
+    }
+
     /// maps something like cargo:cargo-binstall to cargo-binstall and ubi:cargo-binstall, etc
     pub fn all_fulls(&self) -> HashSet<String> {
         let full = self.full();
