@@ -1,6 +1,5 @@
 use color_eyre::eyre::{bail, Result};
 
-use crate::backend::ABackend;
 use crate::cli::args::ToolArg;
 use crate::config::Config;
 use crate::toolset::ToolRequest;
@@ -36,7 +35,7 @@ impl Latest {
             _ => bail!("invalid version: {}", self.tool.style()),
         };
 
-        let backend: ABackend = self.tool.backend.into();
+        let backend = self.tool.ba.backend()?;
         let mpr = MultiProgressReport::get();
         if let Some(plugin) = backend.plugin() {
             plugin.ensure_installed(&mpr, false)?;
