@@ -5,12 +5,12 @@ use crate::cli::args::BackendArg;
 use crate::cmd::CmdLineRunner;
 use crate::config::settings::SETTINGS;
 use crate::config::{Config, Settings};
+use crate::file::{TarFormat, TarOptions};
 use crate::http::{HTTP, HTTP_FETCH};
 use crate::install_context::InstallContext;
-use crate::plugins::core::CorePlugin;
 use crate::toolset::ToolVersion;
 use crate::ui::progress_report::SingleReport;
-use crate::{env, file, hash, http};
+use crate::{env, file, hash, http, plugins};
 use eyre::{bail, ensure, Result};
 use serde_derive::Deserialize;
 use std::collections::BTreeMap;
@@ -22,13 +22,13 @@ use xx::regex;
 
 #[derive(Debug)]
 pub struct NodePlugin {
-    core: CorePlugin,
+    ba: BackendArg,
 }
 
 impl NodePlugin {
     pub fn new() -> Self {
         Self {
-            core: CorePlugin::new(BackendArg::new("node", "node")),
+            ba: plugins::core::new_backend_arg("node"),
         }
     }
 
@@ -51,12 +51,15 @@ impl NodePlugin {
         }?;
         let tarball_name = &opts.binary_tarball_name;
         ctx.pr.set_message(format!("extracting {tarball_name}"));
-        let tmp_extract_path = tempdir_in(opts.install_path.parent().unwrap())?;
-        file::untar_gz(&opts.binary_tarball_path, tmp_extract_path.path())?;
         file::remove_all(&opts.install_path)?;
-        file::rename(
-            tmp_extract_path.path().join(slug(&opts.version)),
+        file::untar(
+            &opts.binary_tarball_path,
             &opts.install_path,
+            &TarOptions {
+                format: TarFormat::TarGz,
+                strip_components: 1,
+                pr: Some(ctx.pr.as_ref()),
+            },
         )?;
         Ok(())
     }
@@ -95,7 +98,15 @@ impl NodePlugin {
         )?;
         ctx.pr.set_message(format!("extracting {tarball_name}"));
         file::remove_all(&opts.build_dir)?;
-        file::untar_gz(&opts.source_tarball_path, opts.build_dir.parent().unwrap())?;
+        file::untar(
+            &opts.source_tarball_path,
+            opts.build_dir.parent().unwrap(),
+            &TarOptions {
+                format: TarFormat::TarGz,
+                pr: Some(ctx.pr.as_ref()),
+                ..Default::default()
+            },
+        )?;
         self.exec_configure(ctx, opts)?;
         self.exec_make(ctx, opts)?;
         self.exec_make_install(ctx, opts)?;
@@ -198,7 +209,7 @@ impl NodePlugin {
                 .arg("--global")
                 .arg(package)
                 .envs(config.env()?)
-                .env(&*env::PATH_KEY, CorePlugin::path_env_with_tv_path(tv)?)
+                .env(&*env::PATH_KEY, plugins::core::path_env_with_tv_path(tv)?)
                 .execute()?;
         }
         Ok(())
@@ -217,7 +228,7 @@ impl NodePlugin {
         CmdLineRunner::new(corepack)
             .with_pr(pr)
             .arg("enable")
-            .env(&*env::PATH_KEY, CorePlugin::path_env_with_tv_path(tv)?)
+            .env(&*env::PATH_KEY, plugins::core::path_env_with_tv_path(tv)?)
             .execute()?;
         Ok(())
     }
@@ -234,7 +245,7 @@ impl NodePlugin {
     fn test_npm(&self, config: &Config, tv: &ToolVersion, pr: &dyn SingleReport) -> Result<()> {
         pr.set_message("npm -v".into());
         CmdLineRunner::new(self.npm_path(tv))
-            .env(&*env::PATH_KEY, CorePlugin::path_env_with_tv_path(tv)?)
+            .env(&*env::PATH_KEY, plugins::core::path_env_with_tv_path(tv)?)
             .with_pr(pr)
             .arg("-v")
             .envs(config.env()?)
@@ -253,15 +264,15 @@ impl NodePlugin {
 }
 
 impl Backend for NodePlugin {
-    fn fa(&self) -> &BackendArg {
-        &self.core.fa
+    fn ba(&self) -> &BackendArg {
+        &self.ba
     }
 
     fn get_remote_version_cache(&self) -> Arc<VersionCacheManager> {
         static CACHE: OnceLock<Arc<VersionCacheManager>> = OnceLock::new();
         CACHE
             .get_or_init(|| {
-                CacheManagerBuilder::new(self.fa().cache_path.join("remote_versions.msgpack.z"))
+                CacheManagerBuilder::new(self.ba().cache_path.join("remote_versions.msgpack.z"))
                     .with_fresh_duration(SETTINGS.fetch_remote_versions_cache())
                     .with_cache_key(SETTINGS.node.mirror_url.clone().unwrap_or_default())
                     .with_cache_key(SETTINGS.node.flavor.clone().unwrap_or_default())
